@@ -4,9 +4,9 @@ import requests
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 from syncari.logger import SyncariLogger
-from syncari.models.request import ErrorResponse
+from syncari.models import ErrorResponse
 
-logger = SyncariLogger().get_logger('rest_client')
+logger = SyncariLogger.get_logger('rest_client')
 
 class RetryableException(Exception):
     """Class to mark an ApiException as retryable."""
