@@ -1,9 +1,6 @@
 from abc import ABC, abstractmethod
 import json
-from syncari.models.request import (DescribeRequest, ErrorResponse, ReadResponse,
-    SyncRequest, WebhookRequest, RequestType, Request)
-from syncari.models.core import Connection, EventData, Record, Result, SynapseInfo
-from syncari.models.schema import Schema
+from syncari.models import *
 from syncari.rest.client import SyncariException
 from ..logger import SyncariLogger
 
@@ -106,7 +103,7 @@ class Synapse(ABC):
                 if not isinstance(response, list):
                     raise self.__prep_invalid_response_exception(response)
                 for val in response:
-                    if not isinstance(val, EventData):
+                    if not isinstance(val, Record):
                         raise self.__prep_invalid_response_exception(response)
 
             else:
