@@ -1,8 +1,7 @@
 from abc import abstractmethod
 import json
 from enum import Enum
-from syncari.models.core import (Record, Result)
-from syncari.models.request import ErrorResponse, Request
+from syncari.models import *
 from syncari.rest.client import SyncariRestClient
 from syncari.synapse.abstract_synapse import Synapse
 
@@ -66,6 +65,10 @@ class SimpleRestSynapse(Synapse):
 
     def __crud(self, operation):
         entity_name = self.request.entity.apiName
+        plural_name = self.request.entity.pluralName
+        if not plural_name:
+            plural_name = entity_name
+
         super().print(self.get_by_id.__name__, self.request)
         rest_client = self.get_rest_client() 
         eds = []
@@ -73,13 +76,13 @@ class SimpleRestSynapse(Synapse):
             data = Record.parse_obj(data)
             resp = None
             if operation is CrudOperation.GET:
-                resp = rest_client.get(entity_name + "s" + "/" + data.id, params=rest_client.auth_config, json=data.values)
+                resp = rest_client.get(plural_name + "/" + data.id, params=rest_client.auth_config, json=data.values)
             elif operation is CrudOperation.CREATE:
-                resp = rest_client.post(entity_name + "s", params=rest_client.auth_config, json=data.values)
+                resp = rest_client.post(plural_name, params=rest_client.auth_config, json=data.values)
             elif operation is CrudOperation.UPDATE:
-                resp = rest_client.put(entity_name + "s" + "/" + data.id, params=rest_client.auth_config, json=data.values)
+                resp = rest_client.put(plural_name + "/" + data.id, params=rest_client.auth_config, json=data.values)
             elif operation is CrudOperation.DELETE:
-                resp = rest_client.delete(entity_name + "s" + "/" + data.id, params=rest_client.auth_config)
+                resp = rest_client.delete(plural_name + "/" + data.id, params=rest_client.auth_config)
 
             if type(resp) is ErrorResponse:
                 eds.append(Result(id=data.id,syncariId=data.syncariEntityId,success=False,errors=[str(resp)]))
@@ -89,7 +92,10 @@ class SimpleRestSynapse(Synapse):
                 if operation is CrudOperation.GET:
                     eds.append(self.process_single_row(entity_name, self.request.entity, row))
                 else:
-                    eds.append(Result(id=row[self.id_field],syncariId=data.syncariEntityId,success=True))
+                    id = data.id
+                    if row is not None and isinstance(row, dict) and self.id_field in row:
+                        id = row[self.id_field]
+                    eds.append(Result(id=row[id],syncariId=data.syncariEntityId,success=True))
             
         return eds
 
