@@ -1,11 +1,7 @@
 
 # pylint: disable=missing-class-docstring, import-error, missing-function-docstring
 import json
-from syncari.models.core import (AuthConfig, Connection, AuthType, 
-    AuthField, AuthMetadata, UIMetadata, SynapseInfo, Record, Result,EventData,WebhookOperation)
-from syncari.models.request import (DescribeRequest,
-    Request, SyncRequest, Watermark, WebhookRequest, RequestType, ReadResponse)
-from syncari.models.schema import Schema, Attribute
+from syncari.models import *
 
 from syncari.synapse.abstract_synapse import Synapse
 from syncari.synapse.simple_rest_synapse import SimpleRestSynapse
@@ -71,9 +67,9 @@ class MockSynapse(SimpleRestSynapse):
 
     def process_webhook(self):
         self.__print(self.process_webhook.__name__, self.request)
-        event_datas = []
-        event_datas.append(EventData.parse_obj({'data':Record.parse_obj({'name':'MockRecord','values':{'key':'val'}}),'operation':WebhookOperation.CREATE}))
-        return event_datas
+        eds = []
+        eds.append(Record.parse_obj({'name':'MockRecord','values':{'key':'val'}}))
+        return eds
 
     def process_single_row(self):
         return super().process_single_row()
@@ -170,8 +166,8 @@ def test_process_webook_request():
     synapse = MockSynapse(synapse_request, 'id', 'data')
     resp = json.loads(synapse.execute())
     assert resp is not None
-    mock_event_data = EventData.parse_raw(resp[0])
-    assert mock_event_data.data.name == 'MockRecord'
+    mock_event_data = Record.parse_raw(resp[0])
+    assert mock_event_data.name == 'MockRecord'
 
 
 def get_connection():
